
# Class: DtypeMixin




URI: [nwb_schema_language:DtypeMixin](https://w3id.org/p2p_ld/nwb-schema-language/DtypeMixin)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Dataset]uses%20-.->[DtypeMixin&#124;dtype:string%20*],[Attribute]uses%20-.->[DtypeMixin],[Dataset],[Attribute])](https://yuml.me/diagram/nofunky;dir:TB/class/[Dataset]uses%20-.->[DtypeMixin&#124;dtype:string%20*],[Attribute]uses%20-.->[DtypeMixin],[Dataset],[Attribute])

## Mixin for

 * [Attribute](Attribute.md) (mixin) 
 * [Dataset](Dataset.md) (mixin) 

## Referenced by Class


## Attributes


### Own

 * [dtype](dtype.md)  <sub>0..\*</sub>
     * Range: [String](types/String.md)
